@@ -1,22 +1,21 @@
 #' @include datasets.R
 NULL
 
-#' Launch Shiny app
+#' Open TestDesign app
 #'
-#' Launch Shiny app locally.
+#' \code{\link{TestDesign}} is a caller function to open the Shiny interface of TestDesign package.
 #'
 #' @examples
+#'
+#' \dontrun{
 #' if (interactive()) {
-#'   OAT()
-#'   ## or
-#'   app()
+#'   TestDesign()
+#' }
 #' }
 #'
-#' @aliases app
-#' @rdname OAT
+#' @rdname TestDesign
 #' @export
-
-OAT <- function() {
+TestDesign <- function() {
   app_dir <- system.file("shiny", package = "TestDesign")
   if (app_dir == "") {
     stop("Could not find the application directory. Try re-installing `TestDesign`.", call. = FALSE)
@@ -46,9 +45,28 @@ OAT <- function() {
   }
 }
 
-#' @rdname OAT
+#' Open TestDesign app
+#'
+#' \code{\link{app}} and \code{\link{OAT}} are aliases of \code{\link{TestDesign}}.
+#'
+#' \code{\link{TestDesign}} is a caller function to open the Shiny interface of TestDesign package.
+#'
+#' @examples
+#'
+#' \dontrun{
+#' if (interactive()) {
+#'   TestDesign()
+#' }
+#' }
+#'
+#' @rdname TestDesign_alias
 #' @export
-
 app <- function() {
-  OAT()
+  TestDesign()
+}
+
+#' @rdname TestDesign_alias
+#' @export
+OAT <- function() {
+  TestDesign()
 }
